@@ -1,23 +1,13 @@
-/* This file is part of Step
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "test_metaobject.h"
+
 #include "stepcore/object.h"
+
 #include <QString>
 #include <QMetaType>
 #include <QTest>
@@ -101,14 +91,14 @@ void TestMetaobject::testMetaObject()
 {
     /* Abstract class: can't create */
     QVERIFY( MetaObjectTestInterface::staticMetaObject()->isAbstract() );
-    QVERIFY( MetaObjectTestInterface::staticMetaObject()->newObject() == NULL );
+    QVERIFY( MetaObjectTestInterface::staticMetaObject()->newObject() == nullptr );
 
     /* Normal class: should create */
     QVERIFY( !MetaObjectTestObject::staticMetaObject()->isAbstract() );
     StepCore::Object* object = MetaObjectTestObject::staticMetaObject()->newObject();
-    QVERIFY( object != NULL);
+    QVERIFY( object != nullptr);
     MetaObjectTestObject* testObject = dynamic_cast<MetaObjectTestObject*>(object);
-    QVERIFY( testObject != NULL );
+    QVERIFY( testObject != nullptr );
     
     QVERIFY( object->metaObject() == MetaObjectTestObject::staticMetaObject() );
 
@@ -143,7 +133,7 @@ void TestMetaobject::testMetaObject()
     QVERIFY( metaObject->property("property2") == metaObject->property(2) );
     QVERIFY( metaObject->property("property3") == metaObject->property(3) );
     QVERIFY( metaObject->property("property4") == metaObject->property(4) );
-    QVERIFY( metaObject->property("notProperty") == NULL );
+    QVERIFY( metaObject->property("notProperty") == nullptr );
 
     const StepCore::MetaProperty* property;
 
