@@ -1,20 +1,8 @@
-/* This file is part of Step.
- *   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
- * 
- *   Step is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
- * 
- *   Step is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- * 
- *   You should have received a copy of the GNU General Public License
- *   along with Step; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "clipboard.h"
 
@@ -103,7 +91,7 @@ void CopyHelper::fixItemLinks(StepCore::Item* item)
         if (pr->userTypeId() == qMetaTypeId<StepCore::Object*>()) {
             QVariant v = pr->readVariant(item);
             StepCore::Object *obj = v.value<StepCore::Object*>();
-            StepCore::Object *copy = _copyMap.value(obj, 0); 
+            StepCore::Object *copy = _copyMap.value(obj, nullptr);
             pr->writeVariant(item, QVariant::fromValue(copy));
         }
     }
