@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mainwindow.h"
@@ -47,6 +35,7 @@
 #include <QStatusBar>
 #include <QTemporaryFile>
 
+#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KConfig>
 #include <KConfigDialog>
@@ -55,18 +44,18 @@
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KNS3/DownloadDialog>
+#include <KNSWidgets/Action>
 #include <KRecentFilesAction>
 #include <KStandardAction>
 #include <KToolBarPopupAction>
 
+#include <QActionGroup>
 #include <cstdlib>
 #include <ctime>
 
 MainWindow::MainWindow()
 {
-    qsrand(time(NULL));
-    std::srand(time(NULL));
+    std::srand(time(nullptr));
 
     // Load UnitCalc at startup
     UnitsCalc::self();
@@ -169,10 +158,8 @@ void MainWindow::setupActions()
     actionUploadExample->setText(i18n("Share C&urrent Experiment..."));
     actionUploadExample->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
 
-    QAction * actionDownloadExamples = actionCollection()->add<QAction>(
-                QStringLiteral("file_example_download"), this, SLOT(downloadExamples()));
-    actionDownloadExamples->setText(i18n("&Download New Experiments..."));
-    actionDownloadExamples->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+    KNSWidgets::Action *actionDownloadExamples = new KNSWidgets::Action(i18n("&Download New Experiments..."), QStringLiteral("step.knsrc"), actionCollection());
+    actionCollection()->addAction(QStringLiteral("file_example_download"), actionDownloadExamples);
 
     /* Edit menu */
     actionRedo = KStandardAction::redo(worldModel->undoStack(), SLOT(redo()), actionCollection());
@@ -327,7 +314,7 @@ bool MainWindow::openFile(const QUrl& url, const QUrl& startUrl)
     QFile file(fileUrl.path());
     
     if(!worldModel->loadXml(&file)) {
-        KMessageBox::sorry(this, i18n("Cannot parse file '%1': %2", fileUrl.url(QUrl::PreferLocalFile),
+        KMessageBox::error(this, i18n("Cannot parse file '%1': %2", fileUrl.url(QUrl::PreferLocalFile),
                                                     worldModel->errorString()));
         return false;
     }
@@ -363,13 +350,13 @@ bool MainWindow::saveFileAs(const QUrl& url, const QUrl& startUrl)
     }
 
     if(!file->open(QIODevice::WriteOnly | QIODevice::Text)) {
-        KMessageBox::sorry(this, i18n("Cannot open file '%1'", file->fileName()));
+        KMessageBox::error(this, i18n("Cannot open file '%1'", file->fileName()));
         delete file;
         return false;
     }
     
     if(!worldModel->saveXml(file)) {
-        KMessageBox::sorry(this, i18n("Cannot save file '%1': %2",
+        KMessageBox::error(this, i18n("Cannot save file '%1': %2",
 				      fileUrl.url(QUrl::PreferLocalFile),
 				      worldModel->errorString()));
         delete file;
@@ -405,10 +392,18 @@ bool MainWindow::saveFile()
 bool MainWindow::maybeSave()
 {
     if(!worldModel->undoStack()->isClean()) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+         int ret = KMessageBox::warningTwoActionsCancel(this,
+#else
          int ret = KMessageBox::warningYesNoCancel(this, 
+#endif
               i18n("The experiment has been modified.\nDo you want to save your changes?"),
               i18n("Warning - Step"), KStandardGuiItem::save(), KStandardGuiItem::discard());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+         if (ret == KMessageBox::PrimaryAction) return saveFile();
+#else
          if (ret == KMessageBox::Yes) return saveFile();
+#endif
          else if(ret == KMessageBox::Cancel) return false;
     }
     return true;
@@ -454,7 +449,7 @@ void MainWindow::openLocalExample()
 
 void MainWindow::uploadExample()
 {
-    KMessageBox::sorry(this, i18n("Uploading is still not implemented in kdelibs."),
+    KMessageBox::error(this, i18n("Uploading is still not implemented in kdelibs."),
                         i18n("Sorry - Step"));
     /*
     int ret = KMessageBox::questionYesNo(this,
@@ -474,13 +469,6 @@ void MainWindow::uploadExample()
     */
 }
 
-void MainWindow::downloadExamples()
-{
-    //qDebug() << "inside MainWindow::downloadExamples()";
-    KNS3::DownloadDialog dialog(QStringLiteral("step.knsrc"), this);
-    dialog.exec();
-}
-
 void MainWindow::simulationStartStop()
 {
     if(worldModel->isSimulationActive()) simulationStop();
@@ -504,16 +492,16 @@ void MainWindow::simulationStopped(int result)
 
     undoBrowser->setUndoEnabled(true);
     if(result == StepCore::Solver::ToleranceError) {
-        KMessageBox::sorry(this, i18n("Cannot finish this step because local error "
+        KMessageBox::error(this, i18n("Cannot finish this step because local error "
                "is greater than local tolerance.\n"
                "Please check solver settings and try again."));
     } else if(result == StepCore::Solver::IntersectionDetected || 
               result == StepCore::Solver::CollisionDetected) {
-        KMessageBox::sorry(this, i18n("Cannot finish this step because there are collisions "
+        KMessageBox::error(this, i18n("Cannot finish this step because there are collisions "
                "which cannot be resolved automatically.\n"
                "Please move colliding objects apart and try again."));
     } else if(result != StepCore::Solver::OK) {
-        KMessageBox::sorry(this, i18n("Cannot finish this step because of an unknown error."));
+        KMessageBox::error(this, i18n("Cannot finish this step because of an unknown error."));
     }
 }
 
@@ -581,7 +569,7 @@ void MainWindow::configureStep()
     KConfigDialog* dialog = new KConfigDialog(this, QStringLiteral("settings"), Settings::self());
 
     Ui::ConfigureStepGeneralWidget generalUi;
-    QWidget* generalWidget = new QWidget(0);
+    QWidget* generalWidget = new QWidget(nullptr);
     generalWidget->setObjectName(QStringLiteral("general"));
     generalUi.setupUi(generalWidget);
     dialog->addPage(generalWidget, i18n("General"), QStringLiteral("step")); //shows the "step" icon, the "general" icon doesn't exist
