@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "polygongraphics.h"
@@ -37,7 +25,7 @@
 RigidBodyGraphicsItem::RigidBodyGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : StepGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::RigidBody*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::RigidBody*>(_item) != nullptr);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     setAcceptHoverEvents(true);
@@ -171,7 +159,7 @@ bool DiskCreator::sceneEvent(QEvent* event)
 
         _worldModel->simulationPause();
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
-        _item = _worldModel->createItem(_className); Q_ASSERT(_item != NULL);
+        _item = _worldModel->createItem(_className); Q_ASSERT(_item != nullptr);
         _worldModel->setProperty(_item, QStringLiteral("position"), vpos);
         _worldModel->setProperty(_item, QStringLiteral("radius"), QVariant::fromValue(0.0));
         _worldModel->addItem(_item);
@@ -233,7 +221,7 @@ void DiskVertexHandlerGraphicsItem::setValue(const StepCore::Vector2d& value)
 DiskGraphicsItem::DiskGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : RigidBodyGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::Disk*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::Disk*>(_item) != nullptr);
 }
 
 inline StepCore::Disk* DiskGraphicsItem::disk() const
@@ -263,7 +251,7 @@ void DiskGraphicsItem::viewScaleChanged()
 	// Don't need a marker when the disk is too small to see in detail.
     }
 
-    _markPath = QMatrix().rotate(disk()->angle() * 180 / StepCore::Constants::Pi).map(_markPath);
+    _markPath = QTransform().rotate(disk()->angle() * 180 / StepCore::Constants::Pi).map(_markPath);
     RigidBodyGraphicsItem::viewScaleChanged();
 }
 
@@ -284,7 +272,7 @@ OnHoverHandlerGraphicsItem* DiskGraphicsItem::createOnHoverHandler(const QPointF
     if(num >= 0)
         return new DiskVertexHandlerGraphicsItem(_item, _worldModel, this, num);
 
-    return 0;
+    return nullptr;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////
@@ -305,7 +293,7 @@ bool BoxCreator::sceneEvent(QEvent* event)
 
         _worldModel->simulationPause();
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
-        _item = _worldModel->createItem(_className); Q_ASSERT(_item != NULL);
+        _item = _worldModel->createItem(_className); Q_ASSERT(_item != nullptr);
         _worldModel->setProperty(_item, QStringLiteral("position"), vpos);
         _worldModel->setProperty(_item, QStringLiteral("size"), QVariant::fromValue(StepCore::Vector2d::Zero().eval()));
         _worldModel->addItem(_item);
@@ -450,7 +438,7 @@ bool PolygonCreator::sceneEvent(QEvent* event)
 
         _worldModel->simulationPause();
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
-        _item = _worldModel->createItem(_className); Q_ASSERT(_item != NULL);
+        _item = _worldModel->createItem(_className); Q_ASSERT(_item != nullptr);
         _worldModel->setProperty(_item, QStringLiteral("position"), vpos);
         _worldModel->setProperty(_item, QStringLiteral("vertexes"), QStringLiteral("(0,0)"));
         _worldModel->addItem(_item);
@@ -513,7 +501,7 @@ bool PolygonCreator::sceneEvent(QEvent* event)
 BasePolygonGraphicsItem::BasePolygonGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : RigidBodyGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::BasePolygon*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::BasePolygon*>(_item) != nullptr);
 }
 
 inline StepCore::BasePolygon* BasePolygonGraphicsItem::basePolygon() const
@@ -532,7 +520,7 @@ void BasePolygonGraphicsItem::viewScaleChanged()
             _painterPath.lineTo(vectorToPoint( basePolygon()->vertexes()[i] ));
         }
         _painterPath.closeSubpath();
-        _painterPath = QMatrix().rotate(basePolygon()->angle() * 180 / StepCore::Constants::Pi).map(_painterPath);
+        _painterPath = QTransform().rotate(basePolygon()->angle() * 180 / StepCore::Constants::Pi).map(_painterPath);
     } else {
         double s = currentViewScale();
         _painterPath.addEllipse(-1/s, -1/s, 2/s, 2/s);
@@ -625,7 +613,7 @@ OnHoverHandlerGraphicsItem* BoxGraphicsItem::createOnHoverHandler(const QPointF&
     if(num >= 0)
         return new BoxVertexHandlerGraphicsItem(_item, _worldModel, this, num);
 
-    return 0;
+    return nullptr;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////
@@ -661,7 +649,7 @@ OnHoverHandlerGraphicsItem* PolygonGraphicsItem::createOnHoverHandler(const QPoi
     if(num >= 0)
         return new PolygonVertexHandlerGraphicsItem(_item, _worldModel, this, num);
 
-    return 0;
+    return nullptr;
 }
 
 inline StepCore::Polygon* PolygonGraphicsItem::polygon() const
