@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "propertiesbrowser.h"
@@ -45,18 +33,18 @@
 class PropertiesBrowserModel: public QAbstractItemModel
 {
 public:
-    PropertiesBrowserModel(WorldModel* worldModel, QObject* parent = 0);
+    PropertiesBrowserModel(WorldModel* worldModel, QObject* parent = nullptr);
 
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role) const override;
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex &index) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
-                         int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+                         int role = Qt::DisplayRole) const override;
 
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
-    bool setData(const QModelIndex &index, const QVariant &value, int role) Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role) override;
 
     void setObject(StepCore::Object* object);
     StepCore::Object* object() { return _object; }
@@ -73,7 +61,7 @@ protected:
 };
 
 PropertiesBrowserModel::PropertiesBrowserModel(WorldModel* worldModel, QObject* parent)
-    : QAbstractItemModel(parent), _worldModel(worldModel), _object(NULL)
+    : QAbstractItemModel(parent), _worldModel(worldModel), _object(nullptr)
 {
     _solverChoices = new ChoicesModel(this);
 
@@ -95,7 +83,7 @@ void PropertiesBrowserModel::setObject(StepCore::Object* object)
     _object = object;
 
     _subRows.clear();
-    if(_object != NULL) {
+    if(_object != nullptr) {
         _worldModel->simulationPause();
 
         _item = dynamic_cast<StepCore::Item*>(_object);
@@ -103,7 +91,7 @@ void PropertiesBrowserModel::setObject(StepCore::Object* object)
             if(_item->world()->errorsCalculation()) _objectErrors = _item->objectErrors();
             else _objectErrors = _item->tryGetObjectErrors();
         } else {
-            _objectErrors = NULL;
+            _objectErrors = nullptr;
         }
 
         for(int i=0; i<_object->metaObject()->propertyCount(); ++i) {
@@ -119,7 +107,7 @@ void PropertiesBrowserModel::setObject(StepCore::Object* object)
 
 void PropertiesBrowserModel::emitDataChanged(bool dynamicOnly)
 {
-    if(_object == NULL) return;
+    if(_object == nullptr) return;
 
     _worldModel->simulationPause();
 
@@ -128,7 +116,7 @@ void PropertiesBrowserModel::emitDataChanged(bool dynamicOnly)
         if(_item->world()->errorsCalculation()) _objectErrors = _item->objectErrors();
         else _objectErrors = _item->tryGetObjectErrors();
     } else {
-        _objectErrors = NULL;
+        _objectErrors = nullptr;
     }
 
     for(int i=0; i<_object->metaObject()->propertyCount(); i++) {
@@ -154,7 +142,7 @@ void PropertiesBrowserModel::emitDataChanged(bool dynamicOnly)
 
 QVariant PropertiesBrowserModel::data(const QModelIndex &index, int role) const
 {
-    if(_object == NULL) return QVariant();
+    if(_object == nullptr) return QVariant();
 
     if(!index.isValid()) return QVariant();
 
@@ -175,7 +163,7 @@ QVariant PropertiesBrowserModel::data(const QModelIndex &index, int role) const
                     p->userTypeId() == qMetaTypeId<StepCore::Vector2d>() ||
                     p->userTypeId() == qMetaTypeId<StepCore::Vector2dList >()) {
                     return _worldModel->formatProperty(_object, _objectErrors, p,
-                                role == Qt::EditRole ? WorldModel::FormatEditable : WorldModel::FormatFlags(0));
+                                role == Qt::EditRole ? WorldModel::FormatEditable : WorldModel::FormatFlags());
                 } else if(p->userTypeId() == qMetaTypeId<StepCore::Object*>()) {
                     return _worldModel->formatName(p->readVariant(_object).value<StepCore::Object*>());
                 } else if(p->userTypeId() == qMetaTypeId<StepCore::Color>()) {
@@ -265,7 +253,7 @@ QVariant PropertiesBrowserModel::data(const QModelIndex &index, int role) const
 
 bool PropertiesBrowserModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
-    if(_object == NULL) return false;
+    if(_object == nullptr) return false;
 
     if(index.isValid() && index.column() == 1 && role == Qt::EditRole) {
         _worldModel->simulationPause();
@@ -278,14 +266,14 @@ bool PropertiesBrowserModel::setData(const QModelIndex &index, const QVariant &v
                     beginResetModel();
                     _worldModel->beginMacro(i18n("Change solver type"));
                     _object = _worldModel->newSolver(value.toString() + "Solver");
-                    Q_ASSERT(_object != NULL);
+                    Q_ASSERT(_object != nullptr);
                     _worldModel->endMacro();
                     endResetModel();
                 }
             } else {
                 const StepCore::MetaProperty* p = _object->metaObject()->property(index.row());
                 const StepCore::MetaProperty* pv = _objectErrors ?
-                        _objectErrors->metaObject()->property(p->name() + "Variance") : NULL;
+                        _objectErrors->metaObject()->property(p->name() + "Variance") : nullptr;
 
                 if(p->userTypeId() == qMetaTypeId<StepCore::Object*>()) {
                     Q_ASSERT(!pv);
@@ -425,7 +413,7 @@ bool PropertiesBrowserModel::setData(const QModelIndex &index, const QVariant &v
 
 QModelIndex PropertiesBrowserModel::index(int row, int column, const QModelIndex &parent) const
 {
-    if(_object == NULL) return QModelIndex();
+    if(_object == nullptr) return QModelIndex();
     if(!parent.isValid()) return createIndex(row, column);
 
     if(parent.internalId() == 0 && _subRows[parent.row()] != 0)
@@ -443,7 +431,7 @@ QModelIndex PropertiesBrowserModel::parent(const QModelIndex& index) const
 
 int PropertiesBrowserModel::rowCount(const QModelIndex &parent) const
 {
-    if(_object == NULL) return 0;
+    if(_object == nullptr) return 0;
     else if(parent.isValid()) {
         if(parent.column() == 0 && parent.internalId() == 0) return _subRows[parent.row()];
         return 0;
@@ -592,12 +580,16 @@ void PropertiesBrowserDelegate::editorActivated()
 class PropertiesBrowserView: public QTreeView
 {
 public:
-    PropertiesBrowserView(QWidget* parent = 0);
+    PropertiesBrowserView(QWidget* parent = nullptr);
 protected:
-    void changeEvent(QEvent* event) Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent* event) Q_DECL_OVERRIDE;
-    void drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const Q_DECL_OVERRIDE;
-    QStyleOptionViewItem viewOptions() const Q_DECL_OVERRIDE;
+    void changeEvent(QEvent* event) override;
+    void mousePressEvent(QMouseEvent* event) override;
+    void drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const override;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void initViewItemOption(QStyleOptionViewItem *option) const override;
+#else
+    QStyleOptionViewItem viewOptions() const override;
+#endif
     const int _windowsDecoSize;
     bool _macStyle;
 };
@@ -639,7 +631,12 @@ void PropertiesBrowserView::mousePressEvent(QMouseEvent* event)
 void PropertiesBrowserView::drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const
 {
     // Inspired by qt-designer code in src/components/propertyeditor/qpropertyeditor.cpp
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QStyleOptionViewItem opt;
+    initViewItemOption(&opt);
+#else
     QStyleOptionViewItem opt = viewOptions();
+#endif
 
     if(model()->hasChildren(index)) {
         opt.state |= QStyle::State_Children;
@@ -664,12 +661,23 @@ void PropertiesBrowserView::drawBranches(QPainter *painter, const QRect &rect, c
     }
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+void PropertiesBrowserView::initViewItemOption(QStyleOptionViewItem *option) const
+{
+    if (!option) {
+        return;
+    }
+    QTreeView::initViewItemOption(option);
+    option->showDecorationSelected = true;
+}
+#else
 QStyleOptionViewItem PropertiesBrowserView::viewOptions() const
 {
     QStyleOptionViewItem option = QTreeView::viewOptions();
     option.showDecorationSelected = true;
     return option;
 }
+#endif
 
 PropertiesBrowser::PropertiesBrowser(WorldModel* worldModel, QWidget* parent)
     : QDockWidget(i18n("Properties"), parent)
@@ -718,7 +726,7 @@ PropertiesBrowser::PropertiesBrowser(WorldModel* worldModel, QWidget* parent)
 
 void PropertiesBrowser::worldModelReset()
 {
-    _propertiesBrowserModel->setObject(NULL);
+    _propertiesBrowserModel->setObject(nullptr);
 }
 
 void PropertiesBrowser::worldCurrentChanged(const QModelIndex& current, const QModelIndex& /*previous*/)
@@ -743,7 +751,7 @@ void PropertiesBrowser::worldRowsRemoved(const QModelIndex& parent, int start, i
     Q_UNUSED(start)
     Q_UNUSED(end)
     if(!_worldModel->objectIndex(_propertiesBrowserModel->object()).isValid())
-        _propertiesBrowserModel->setObject(NULL);
+        _propertiesBrowserModel->setObject(nullptr);
 }
 
 void PropertiesBrowser::currentChanged(const QModelIndex& current, const QModelIndex& /*previous*/)
