@@ -1,20 +1,8 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
-   Copyright (C) 2014 Inge Wallin        <inge@lysator.liu.se>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+    SPDX-FileCopyrightText: 2014 Inge Wallin <inge@lysator.liu.se>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "softbodygraphics.h"
@@ -65,10 +53,10 @@ bool SoftBodyCreator::sceneEvent(QEvent* event)
         showMessage(MessageFrame::Information,
             i18n("Please fill in the parameters for %1", classNameTr()));
 
-        _item = _worldModel->createItem(_className); Q_ASSERT(_item != 0);
+        _item = _worldModel->createItem(_className); Q_ASSERT(_item != nullptr);
         
         SoftBodyMenuHandler* menuHandler =
-            new SoftBodyMenuHandler(_item, _worldModel, 0);
+            new SoftBodyMenuHandler(_item, _worldModel, nullptr);
         menuHandler->createSoftBodyItems(position);
         menuHandler->deleteLater();
         
@@ -81,7 +69,7 @@ bool SoftBodyCreator::sceneEvent(QEvent* event)
         }
         else {
             delete _item;
-            _item = 0;
+            _item = nullptr;
         }
 
         setFinished();
@@ -94,8 +82,8 @@ bool SoftBodyCreator::sceneEvent(QEvent* event)
 
 void SoftBodyMenuHandler::populateMenu(QMenu* menu, KActionCollection* actions)
 {
-    _createSoftBodyItemsUi = 0;
-    _createSoftBodyItemsDialog = 0;
+    _createSoftBodyItemsUi = nullptr;
+    _createSoftBodyItemsDialog = nullptr;
     //_confChanged = false;
 
     // XXX: better icon
@@ -163,8 +151,8 @@ void SoftBodyMenuHandler::createSoftBodyItems(const StepCore::Vector2d& pos)
 	createSoftBodyItemsApply();
     }
 
-    delete _createSoftBodyItemsDialog; _createSoftBodyItemsDialog = 0;
-    delete _createSoftBodyItemsUi; _createSoftBodyItemsUi = 0;
+    delete _createSoftBodyItemsDialog; _createSoftBodyItemsDialog = nullptr;
+    delete _createSoftBodyItemsUi; _createSoftBodyItemsUi = nullptr;
 }
 
 void SoftBodyMenuHandler::createSoftBodyItemsApply()
@@ -209,7 +197,7 @@ void SoftBodyMenuHandler::createSoftBodyItemsApply()
 SoftBodyGraphicsItem::SoftBodyGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : StepGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::SoftBody*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::SoftBody*>(_item) != nullptr);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     setAcceptHoverEvents(true);
