@@ -1,20 +1,8 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
-   Copyright (C) 2014 Inge Wallin        <inge@lysator.liu.se>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+    SPDX-FileCopyrightText: 2014 Inge Wallin <inge@lysator.liu.se>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef STEP_TOOLGRAPHICS_H
@@ -67,7 +55,7 @@ class WidgetVertexHandlerGraphicsItem: public OnHoverHandlerGraphicsItem
 public:
     WidgetVertexHandlerGraphicsItem(StepCore::Item* item, WorldModel* worldModel,
                                         QGraphicsItem* parent, int vertexNum)
-        : OnHoverHandlerGraphicsItem(item, worldModel, parent, NULL, NULL, vertexNum) {}
+        : OnHoverHandlerGraphicsItem(item, worldModel, parent, nullptr, nullptr, vertexNum) {}
 
 
 protected:
@@ -111,7 +99,7 @@ class NoteTextEdit: public KTextEdit
     Q_OBJECT
 
 public:
-    explicit NoteTextEdit(NoteGraphicsItem* noteItem, QWidget* parent = 0)
+    explicit NoteTextEdit(NoteGraphicsItem* noteItem, QWidget* parent = nullptr)
         : KTextEdit(parent), _noteItem(noteItem), _mousePressPoint(-1,-1) {}
     QString emptyNotice() const;
 
@@ -189,10 +177,10 @@ class DataSourceWidget: public QWidget
     Q_OBJECT
 
 public:
-    explicit DataSourceWidget(QWidget* parent = 0);
+    explicit DataSourceWidget(QWidget* parent = nullptr);
 
     void setSkipReadOnly(bool skipReadOnly) { _skipReadOnly = skipReadOnly; }
-    void setDataSource(WorldModel* worldModel, StepCore::Object* object = NULL,
+    void setDataSource(WorldModel* worldModel, StepCore::Object* object = nullptr,
                             const QString& property = QString(), int index = 0);
 
     StepCore::Object* dataObject() const;
@@ -381,7 +369,7 @@ public:
     TracerCreator(const QString& className, WorldModel* worldModel, WorldScene* worldScene)
         : AttachableItemCreator(className, worldModel, worldScene,
                             WorldScene::SnapRigidBody | WorldScene::SnapParticle |
-                            WorldScene::SnapSetLocalPosition, 0) {}
+                            WorldScene::SnapSetLocalPosition, nullptr) {}
 };
 
 class TracerGraphicsItem: public StepGraphicsItem
