@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "worldscene.h"
@@ -35,7 +23,7 @@
 #include <stepcore/rigidbody.h>
 
 #include <QCoreApplication>
-#include <QGLWidget>
+#include <QOpenGLWidget>
 #include <QGraphicsItem>
 #include <QGraphicsSceneMouseEvent>
 #include <QItemSelectionModel>
@@ -51,7 +39,7 @@
 class WorldSceneAxes: public QGraphicsItem
 {
 public:
-    WorldSceneAxes(QGraphicsItem* parent = 0, QGraphicsScene* scene = 0);
+    WorldSceneAxes(QGraphicsItem* parent = nullptr, QGraphicsScene* scene = nullptr);
     QRectF boundingRect() const override;
     QPainterPath shape() const override;
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
@@ -129,9 +117,9 @@ void WorldSceneAxes::viewScaleChanged()
 }
 
 WorldScene::WorldScene(WorldModel* worldModel, QObject* parent)
-    : QGraphicsScene(parent), _worldModel(worldModel), _worldView(0),
-        _currentViewScale(1), _itemCreator(0), _bgColor(0),
-        _sceneAxes(0), _snapItem(0)
+    : QGraphicsScene(parent), _worldModel(worldModel), _worldView(nullptr),
+        _currentViewScale(1), _itemCreator(nullptr), _bgColor(0),
+        _sceneAxes(nullptr), _snapItem(nullptr)
 {
     #ifdef __GNUC__
     #warning TODO: measure what index method is faster
@@ -174,8 +162,8 @@ StepCore::Item* WorldScene::itemFromGraphics(const QGraphicsItem* graphicsItem)
 {
     const StepGraphicsItem* worldGraphicsItem =
             dynamic_cast<const StepGraphicsItem*>(graphicsItem);
-    if(worldGraphicsItem != NULL) return worldGraphicsItem->item();
-    else return NULL;
+    if(worldGraphicsItem != nullptr) return worldGraphicsItem->item();
+    else return nullptr;
 }
 
 StepGraphicsItem* WorldScene::graphicsFromItem(const StepCore::Item* item) const
@@ -188,14 +176,14 @@ void WorldScene::beginAddItem(const QString& name)
     //_currentCreator = name;
     if(_itemCreator) {
         _itemCreator->abort();
-        emit endAddItem(_itemCreator->className(), _itemCreator->item() != NULL);
+        emit endAddItem(_itemCreator->className(), _itemCreator->item() != nullptr);
         delete _itemCreator;
     }
     if(name == QLatin1String("Pointer")) {
-        _itemCreator = NULL;
+        _itemCreator = nullptr;
     } else {
         _itemCreator = _worldModel->worldFactory()->newItemCreator(name, _worldModel, this);
-        Q_ASSERT(_itemCreator != NULL);
+        Q_ASSERT(_itemCreator != nullptr);
         _itemCreator->start();
     }
 }
@@ -214,11 +202,11 @@ bool WorldScene::event(QEvent* event)
     if(_itemCreator) {
         bool handled = _itemCreator->sceneEvent(event);
         if(_itemCreator->finished()) {
-            emit endAddItem(_itemCreator->className(), _itemCreator->item() != NULL);
+            emit endAddItem(_itemCreator->className(), _itemCreator->item() != nullptr);
             // ~ItemCreator() will indirectly call this method, thus we must set
             // the pointer to NULL before deleting the ItemCreator.
             ItemCreator* itemCreator = _itemCreator;
-            _itemCreator = NULL;
+            _itemCreator = nullptr;
             delete itemCreator;
         }
         if(handled) {
@@ -231,7 +219,7 @@ bool WorldScene::event(QEvent* event)
 
 void WorldScene::mousePressEvent(QGraphicsSceneMouseEvent* mouseEvent)
 {
-    if(itemAt(mouseEvent->scenePos(), QTransform()) == NULL) {
+    if(itemAt(mouseEvent->scenePos(), QTransform()) == nullptr) {
         // XXX: how to easily select World ?
         //_worldModel->selectionModel()->clearSelection();
         _worldModel->selectionModel()->setCurrentIndex(_worldModel->worldIndex(), QItemSelectionModel::Clear);
@@ -281,7 +269,7 @@ void WorldScene::worldModelReset()
         delete item;
     }
     _itemsHash.clear();
-    _sceneAxes = 0;
+    _sceneAxes = nullptr;
 
     /* Background */
     if(_bgColor != _worldModel->world()->color()) {
@@ -400,7 +388,7 @@ void WorldScene::worldDataChanged(bool dynamicOnly)
 void WorldScene::updateViewScale()
 {
     if(_worldView) {
-        _currentViewScale = _worldView->matrix().m11();
+        _currentViewScale = _worldView->transform().m11();
         _worldModel->simulationPause();
         foreach (QGraphicsItem *item, items()) {
             StepGraphicsItem* gItem = dynamic_cast<StepGraphicsItem*>(item);
@@ -438,7 +426,7 @@ void WorldScene::snapClear()
 {
     if(_snapItem) {
         _snapItem->setItemHighlighted(false);
-        _snapItem = 0;
+        _snapItem = nullptr;
         _snapToolTip.clear();
         _snapTimer->start();
     }
@@ -451,8 +439,8 @@ StepCore::Item* WorldScene::snapHighlight(QPointF pos, SnapFlags flags, const Sn
     if(flags.testFlag(SnapRigidBody)) types << StepCore::RigidBody::staticMetaObject();
     if(moreTypes) types << *moreTypes;
 
-    StepCore::Item* item = 0;
-    QGraphicsItem* gItem = 0;
+    StepCore::Item* item = nullptr;
+    QGraphicsItem* gItem = nullptr;
     foreach(gItem, items(pos)) {
         item = itemFromGraphics(gItem); if(!item) continue;
         if(flags.testFlag(SnapParticle) && item->metaObject()->inherits<StepCore::Particle>()) break;
@@ -464,7 +452,7 @@ StepCore::Item* WorldScene::snapHighlight(QPointF pos, SnapFlags flags, const Sn
                 if(item->metaObject()->inherits(type)) { found = true; break; }
             if(found) break;
         }
-        item = NULL;
+        item = nullptr;
     }
 
     if(item) {
@@ -480,7 +468,7 @@ StepCore::Item* WorldScene::snapHighlight(QPointF pos, SnapFlags flags, const Sn
 
     } else {
         snapClear();
-        return 0;
+        return nullptr;
     }
 }
 
@@ -555,7 +543,7 @@ void WorldScene::snapUpdateToolTip()
     } else {
         QToolTip::hideText();
         // Hack to hide tooltip immediately
-        QWheelEvent fakeEvent(QPoint(0,0), 0, Qt::NoButton, Qt::NoModifier);
+        QWheelEvent fakeEvent(QPointF(0,0), QPointF(0,0), QPoint(0, 0), QPoint(0, 0), Qt::NoButton, Qt::NoModifier, Qt::NoScrollPhase, false);
         QCoreApplication::sendEvent(_messageFrame, &fakeEvent);
     }
 }
@@ -614,14 +602,14 @@ void WorldGraphicsView::fitToPage()
     //qDebug() << br << " " << (br | QRectF(0,0,0,0)) << endl;
     QRect  ws = viewport()->rect();
 
-    double currentViewScale = matrix().m11();
+    double currentViewScale = transform().m11();
     double s = qMin( ws.width()/br.width(), ws.height()/br.height() );
 
     // XXX: use QSize::scale !
 
     if(s < currentViewScale || s*0.8 > currentViewScale) {
         s *= 0.9;
-        resetMatrix();
+        resetTransform();
         scale(s, -s);
         updateSceneRect();
     } else {
@@ -636,7 +624,7 @@ void WorldGraphicsView::fitToPage()
 
 void WorldGraphicsView::actualSize()
 {
-    resetMatrix();
+    resetTransform();
     scale(100, -100);
     updateSceneRect();
     
@@ -647,14 +635,14 @@ void WorldGraphicsView::actualSize()
 
 void WorldGraphicsView::settingsChanged()
 {
-    if(qobject_cast<QGLWidget*>(viewport())) {
+    if(qobject_cast<QOpenGLWidget*>(viewport())) {
         if(!Settings::enableOpenGL()) setViewport(new QWidget(this));
     } else {
-        if(Settings::enableOpenGL() && QGLFormat::hasOpenGL()) {
+        if(Settings::enableOpenGL()) {
             //qDebug() << "enable OpenGL" << endl;
-            setViewport(new QGLWidget(QGLFormat(QGL::SampleBuffers), this));
-            if(!qobject_cast<QGLWidget*>(viewport())) {
-                qDebug() << "can't create QGLWidget!" << endl;
+            setViewport(new QOpenGLWidget(this));
+            if(!qobject_cast<QOpenGLWidget*>(viewport())) {
+                qDebug() << "can't create QOpenGLWidget!" << Qt::endl;
             }
         }
     }
